/*****************/
/** QapTcha CSS **/
/*****************/
.QapTcha {float:left;margin-top:20px;width:252px;}
.QapTcha .clr{clear:both}
.QapTcha .bgSlider {width:252px;height:37px;float:left;border:1px solid #040404;background-color:#101010;}
.QapTcha .Slider {width:52px;height:37px;background:transparent url('../images/bg_draggable_qaptcha.jpg') no-repeat;cursor:e-resize;position:relative;top:0;left:0}
.QapTcha .TxtStatus {width:252px;margin-top:7px;text-align:left;color:#bb2828;font-family:Verdana;font-size:10px;clear:both}
.QapTcha .dropSuccess {color:#4e8b37}
.QapTcha .dropError {color:#bb2828}